%% MATLAB Group Objects
%  Group objects enable you to treat a number of axes child objects as one group. 
%
%  For example, you can make the entire group visible or invisible.

%% Example

Y = rand(5);
disp(Y)


%% barseries
%    BAR(X,Y) draws the columns of the M-by-N matrix Y as M groups of N
%    vertical bars.  The vector X must not have duplicate values.
%
%    BAR(Y) uses the default value of X=1:M.  For vector inputs, BAR(X,Y)
%    or BAR(Y) draws LENGTH(Y) bars.  The colors are set by the colormap.
%
%    H = BAR(...) returns a vector of handles to barseries objects.

hb = bar(Y); % displays 5 barseries objects


%% create group
% You create a group by parenting axes children to an hggroup or
% hgtransform object:

hg = hggroup;
set(hb,'Parent',hg) % parent the barseries to the hggroup


%% make it invisible

set(hg,'Visible','off') % makes all barseries invisible


%% make it visible again

set(hg,'Visible','on'); % turn it back on
